<!--
Copyright © 2012-2023 jrnl contributors
License: https://www.gnu.org/licenses/gpl-3.0.html
-->

# コマンドライン参照

## 概要

```
使用法: jrnl [--debug] [--help] [--version] [--list] [--encrypt] [--decrypt]
            [--import] [-on DATE] [-today-in-history] [-month DATE]
            [-day DATE] [-year DATE] [-from DATE] [-to DATE] [-contains TEXT]
            [-and] [-starred] [-n [NUMBER]] [-not [TAG]] [--edit] [--delete]
            [--format TYPE] [--tags] [--short]
            [--config-override CONFIG_KEY CONFIG_VALUE]
            [--config-file CONFIG_FILE_PATH]
            [[...]]
```

## スタンドアロンコマンド

これらのコマンドは完了後に終了します。一度に1つだけ実行できます。

### --help

ヘルプメッセージを表示します。

### --version

バージョンとライセンス情報を表示します。

### --list

設定ファイルの場所、設定されているすべてのジャーナル、およびそれらの場所を一覧表示します。

### --encrypt

ジャーナルを暗号化します。詳細は[暗号化](encryption.md)を参照してください。

### --decrypt

ジャーナルを復号化します。詳細は[暗号化](encryption.md)を参照してください。

### --import

他のジャーナルからエントリーをインポートします。同じ内容とタイムスタンプを持つエントリーがある場合、重複は排除されます。

オプションパラメータ：

```sh
--file FILENAME
```

インポートするファイルを指定します。指定されない場合、`jrnl`はSTDINをデータソースとして使用します。

```sh
--format TYPE
```

インポートされるファイルのフォーマットを指定します。デフォルトはjrnlが使用するのと同じデータ保存方法です。詳細は[フォーマット](formats.md)を参照してください。

## 新しいエントリーの書き込み

[基本的な使用方法](usage.md)を参照してください。

## 検索

ジャーナルからエントリーを見つけるには、以下のフィルターの任意の組み合わせを使用します。
すべてのフィルターに一致するエントリーのみが表示されます。

日付を指定する際は、新しいエントリーで使用するのと同じ種類の日付を使用できます。
例えば、`yesterday`、`today`、`Tuesday`、または`2021-08-01`などです。

| 検索引数          | 説明                                                                                                            |
| ----------------- | --------------------------------------------------------------------------------------------------------------- |
| -on DATE          | この日付のエントリーを表示                                                                                      |
| -today-in-history | 年をまたいで今日の日付のエントリーを表示                                                                        |
| -month DATE       | 任意の年のこの月のエントリーを表示                                                                              |
| -day DATE         | 任意の月のこの日のエントリーを表示                                                                              |
| -year DATE        | 特定の年のエントリーを表示                                                                                      |
| -from DATE        | この日付以降（この日を含む）のエントリーを表示                                                                  |
| -to DATE          | この日付以前（この日を含む）のエントリーを表示（別名: -until）                                                  |
| -contains TEXT    | 特定のテキストを含むエントリーを表示（スペースを含むテキストは引用符で囲む）                                    |
| -and              | すべての条件に一致するエントリーのみを表示、"x AND y"と言うのと同じ（デフォルト: OR）                           |
| -starred          | スター付きのエントリーのみを表示（\*でマークされたもの）                                                        |
| -tagged           | タグ付きのエントリーのみを表示（[設定されたtagsymbols](reference-config-file.md#tagsymbols)でマークされたもの） |
| -n [NUMBER]       | 最大NUMBER個のエントリーを表示（注: '-n 3'と'-3'は同じ効果）                                                    |
| -not [TAG]        | このタグを持つエントリーを除外                                                                                  |
| -not -starred     | スター付きのエントリーを除外                                                                                    |
| -not -tagged      | タグ付きのエントリーを除外                                                                                      |

## 検索オプション

これらは検索で選択されたエントリーでさまざまなタスクを実行するのに役立ちます。
単独で使用した場合（検索なし）、ジャーナル全体に対して動作します。

### --edit

選択されたエントリーを設定されたエディタで開きます。設定ファイルに`editor`キーが
設定されていない場合は失敗します。

編集を開始すると、エディタでテキストを修正することで複数のエントリーを追加したり
削除したりできます。エディタを閉じると、jrnlは編集していた一時ファイルを読み取り、
ジャーナルに変更を加えます。

### --delete

選択されたエントリーを対話的に削除します。各エントリーの削除を確認するよう求められます。

### --change-time DATE

選択されたエントリーの時間を指定された日付に、または日付が指定されていない場合は
現在の時刻に対話的に変更します。各エントリーの確認を求められますが、単一のエントリーに
対して`--edit`と一緒に使用している場合は除きます。

### --format TYPE

選択されたエントリーを別のフォーマットで表示します。[フォーマット](formats.md)を参照してください。

#### オプションパラメータ

```sh
--file FILENAME
```

出力をSTDOUTの代わりにファイルに書き込みます。ほとんどのシェルでは、
`>`を使用して同じ効果を得ることができます。

### --tags

'--format tags'のエイリアスです。検索されたエントリー内のすべてのタグとその出現回数の
リストを返します。タグが見つからない場合、`jrnl`はその旨のメッセージを出力します。

### --short

検索されたエントリーの日付とタイトルのみを表示します。

## 設定引数

### --config-override CONFIG_KEY CONFIG_VALUE

このコマンド呼び出しのみ、設定されたキーと値のペアをCONFIG_KV_PAIRで上書きします。
トップレベルにないconfig keyにアクセスするには、キーをドットで区切ります。
例えば、`colors`キー内の`title`キーにアクセスするには`colors.title`を使用します。
例については[高度な使用方法](./advanced.md)を参照してください。

### --config-file CONFIG_FILE_PATH

このコマンド呼び出しのみ、CONFIG_FILE_PATHにある設定ファイルを使用します。
例については[高度な使用方法](./advanced.md)を参照してください。

## その他の引数

### --debug

`jrnl`の実行中にトラブルシューティングに役立つ情報を出力します。

### --diagnostic

[問題を報告する](https://github.com/jrnl-org/jrnl/issues)際に役立つ診断情報を出力します。

